==> SyL-0.15.8.tar.gz: SyL/opt/setup/apps/setup/actions/Project.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2008 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: Project.php,v 1.5 2008/09/29 14:41:37 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * ץȺ饹
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2008 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: Project.php,v 1.5 2008/09/29 14:41:37 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class Project extends AppAction
{
    var $c_action; // 󥸥
    var $c_application; // 󥸥
    var $c_controller; // 󥸥
    var $c_template; // 󥸥
    var $c_project; // 󥸥

    /**
     * ץȺ
     *
     * @access public
     * @param object ǡ֥
     * @param object ƥȥ֥
     */
    function execute(&$data, &$context)
    {
        $project_dir     = $data->geta('d', 0);
        $app_name        = $data->geta('w', 0);
        $is_controller   = $data->is('c');
        $controller_file = $data->geta('c', 0);
        $smarty_dir      = $data->geta('s', 0);

        $cmd =& $context->getConsole();

        // -------------------------------------------------
        // ץȥǥ쥯ȥå
        // -------------------------------------------------
        if (!$project_dir) {
            trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
            exit;
        }
        if (!preg_match('/(\\\\|\/)$/', $project_dir)) {
            $project_dir .= '/';
        }
        if (file_exists($project_dir)) {
            if (!is_writable($project_dir)) {
                trigger_error("[SyL error] Project directory permission denied ({$project_dir})", E_USER_ERROR);
                exit;
            }
        } else {
            if ($cmd->getInput('', "create project ({$project_dir}) [Y/n]:") != 'Y') {
                $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                exit;
            }
        }

        // -------------------------------------------------
        // ץꥱ̾å
        // -------------------------------------------------
        if (!$app_name) {
            trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
            exit;
        } else if (!preg_match('/^[\w\-]+$/', $app_name)) {
            trigger_error("[SyL error] Application name format invalid. ([a-z][A-Z][0-9]-_ only)", E_USER_ERROR);
            exit;
        }

        $app_dir = "{$project_dir}apps/{$app_name}/";

        if (file_exists($app_dir)) {
            if ($cmd->getInput('Already application directory exists', "overwrite application ({$app_dir}) [Y/n]:") != 'Y') {
                $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                exit;
            }
            if (!is_writable($app_dir)) {
                trigger_error("[SyL error] Application directory permission denied ({$app_dir})", E_USER_ERROR);
                exit;
            }
        } else {
            if ($cmd->getInput('', "create application ({$app_dir}) [Y/n]:") != 'Y') {
                $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                exit;
            }
        }

        // -------------------------------------------------
        // ȥեå
        // -------------------------------------------------
        if ($is_controller) {
            if (!$controller_file) {
                // ǥեȤΥȥե
                $controller_file = "{$project_dir}public/{$app_name}.php";
            }
            if (file_exists($controller_file)) {
                if ($cmd->getInput('Already controller file exists', "overwrite controller file ({$controller_file}) [Y/n]:") != 'Y') {
                    $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                    exit;
                }
                if (!is_writable($controller_file)) {
                    trigger_error("[SyL error] Controller file permission denied ({$controller_file})", E_USER_ERROR);
                    exit;
                }
            } else {
                if (is_dir(dirname($controller_file))) {
                    if (!is_writable(dirname($controller_file))) {
                        trigger_error("[SyL error] Controller file permission denied ({$controller_file})", E_USER_ERROR);
                        exit;
                    }
                }
            }
        }

        // -------------------------------------------------
        // SMARTY_DIRå
        // -------------------------------------------------
        if ($smarty_dir) {
            if (!is_dir($smarty_dir)) {
                trigger_error("[SyL error] Smarty dir not found", E_USER_ERROR);
                exit;
            }
            if (!preg_match('/(\\\\|\/)$/', $smarty_dir)) {
                $smarty_dir .= '/';
            }
            if (!is_file($smarty_dir . 'Smarty.class.php')) {
                trigger_error("[SyL error] `Smarty.class.php' not found ({$smarty_dir}Smarty.class.php)", E_USER_ERROR);
                exit;
            }
        }

        // -------------------------------------------------
        // եå
        // -------------------------------------------------
        $action_files = array('index');

        // -------------------------------------------------
        // ƥץ졼ȥեå
        // -------------------------------------------------
        $template_files = array('index');

        // -------------------------------------------------
        // ץȺ
        // -------------------------------------------------
        $this->c_project->trigger($cmd, $project_dir, $smarty_dir);

        // -------------------------------------------------
        // ץꥱ
        // -------------------------------------------------
        $this->c_application->trigger($cmd, $project_dir, $app_name);

        // -------------------------------------------------
        // ȥե
        // -------------------------------------------------
        if ($controller_file) {
            $this->c_controller->trigger($cmd, $project_dir, $app_name, $controller_file);
        }

        // -------------------------------------------------
        // ե
        // -------------------------------------------------
        $this->c_action->trigger($cmd, $project_dir, $app_name, $action_files);

        // -------------------------------------------------
        // ƥץ졼ȥե
        // -------------------------------------------------
        $this->c_template->trigger($cmd, $project_dir, $app_name, $template_files);
    }

}

?>

==> SyL-0.16.1.tar.gz: SyL/opt/setup/apps/setup/actions/Project.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2009 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    Koki Watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2009 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: Project.php,v 1.6 2009/01/11 05:34:33 seasonstream Exp $
 * @link      http://syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * プロジェクト作成クラス
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2009 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: Project.php,v 1.6 2009/01/11 05:34:33 seasonstream Exp $
 * @link      http://syl.jp/
 */
class Project extends AppAction
{
    var $c_action; // インジェクション
    var $c_application; // インジェクション
    var $c_controller; // インジェクション
    var $c_template; // インジェクション
    var $c_project; // インジェクション

    /**
     * プロジェクト作成処理
     *
     * @access public
     * @param object データオブジェクト
     * @param object コンテキストオブジェクト
     */
    function execute(&$data, &$context)
    {
        $project_dir     = $data->geta('d', 0);
        $app_name        = $data->geta('w', 0);
        $is_controller   = $data->is('c');
        $controller_file = $data->geta('c', 0);
        $smarty_dir      = $data->geta('s', 0);

        $cmd =& $context->getConsole();

        // -------------------------------------------------
        // プロジェクトディレクトリチェック
        // -------------------------------------------------
        if (!$project_dir) {
            trigger_error("[SyL error] Project directory (-d) not found", E_USER_ERROR);
            exit;
        }
        if (!preg_match('/(\\\\|\/)$/', $project_dir)) {
            $project_dir .= '/';
        }
        if (file_exists($project_dir)) {
            if (!is_writable($project_dir)) {
                trigger_error("[SyL error] Project directory permission denied ({$project_dir})", E_USER_ERROR);
                exit;
            }
        } else {
            if ($cmd->getInput('', "create project ({$project_dir}) [Y/n]:") != 'Y') {
                $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                exit;
            }
        }

        // -------------------------------------------------
        // アプリケーション名チェック
        // -------------------------------------------------
        if (!$app_name) {
            trigger_error("[SyL error] Application name (-w) not found", E_USER_ERROR);
            exit;
        } else if (!preg_match('/^[\w\-]+$/', $app_name)) {
            trigger_error("[SyL error] Application name format invalid. ([a-z][A-Z][0-9]-_ only)", E_USER_ERROR);
            exit;
        }

        $app_dir = "{$project_dir}apps/{$app_name}/";

        if (file_exists($app_dir)) {
            if ($cmd->getInput('Already application directory exists', "overwrite application ({$app_dir}) [Y/n]:") != 'Y') {
                $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                exit;
            }
            if (!is_writable($app_dir)) {
                trigger_error("[SyL error] Application directory permission denied ({$app_dir})", E_USER_ERROR);
                exit;
            }
        } else {
            if ($cmd->getInput('', "create application ({$app_dir}) [Y/n]:") != 'Y') {
                $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                exit;
            }
        }

        // -------------------------------------------------
        // コントローラファイルチェック
        // -------------------------------------------------
        if ($is_controller) {
            if (!$controller_file) {
                // デフォルトのコントローラファイル
                $controller_file = "{$project_dir}public/{$app_name}.php";
            }
            if (file_exists($controller_file)) {
                if ($cmd->getInput('Already controller file exists', "overwrite controller file ({$controller_file}) [Y/n]:") != 'Y') {
                    $cmd->stdout('*** ' . $data->get(0) . ' stopped');
                    exit;
                }
                if (!is_writable($controller_file)) {
                    trigger_error("[SyL error] Controller file permission denied ({$controller_file})", E_USER_ERROR);
                    exit;
                }
            } else {
                if (is_dir(dirname($controller_file))) {
                    if (!is_writable(dirname($controller_file))) {
                        trigger_error("[SyL error] Controller file permission denied ({$controller_file})", E_USER_ERROR);
                        exit;
                    }
                }
            }
        }

        // -------------------------------------------------
        // SMARTY_DIRチェック
        // -------------------------------------------------
        if ($smarty_dir) {
            if (!is_dir($smarty_dir)) {
                trigger_error("[SyL error] Smarty dir not found", E_USER_ERROR);
                exit;
            }
            if (!preg_match('/(\\\\|\/)$/', $smarty_dir)) {
                $smarty_dir .= '/';
            }
            if (!is_file($smarty_dir . 'Smarty.class.php')) {
                trigger_error("[SyL error] `Smarty.class.php' not found ({$smarty_dir}Smarty.class.php)", E_USER_ERROR);
                exit;
            }
        }

        // -------------------------------------------------
        // アクションファイルチェック
        // -------------------------------------------------
        $action_files = array('index');

        // -------------------------------------------------
        // テンプレートファイルチェック
        // -------------------------------------------------
        $template_files = array('index');

        // -------------------------------------------------
        // プロジェクト作成
        // -------------------------------------------------
        $this->c_project->trigger($cmd, $project_dir, $smarty_dir);

        // -------------------------------------------------
        // アプリケーション作成
        // -------------------------------------------------
        $this->c_application->trigger($cmd, $project_dir, $app_name);

        // -------------------------------------------------
        // コントローラファイル作成
        // -------------------------------------------------
        if ($controller_file) {
            $this->c_controller->trigger($cmd, $project_dir, $app_name, $controller_file);
        }

        // -------------------------------------------------
        // アクションファイル作成
        // -------------------------------------------------
        $this->c_action->trigger($cmd, $project_dir, $app_name, $action_files);

        // -------------------------------------------------
        // テンプレートファイル作成
        // -------------------------------------------------
        $this->c_template->trigger($cmd, $project_dir, $app_name, $template_files);
    }

}
